pub struct RowCount { /* private fields */ }Expand description
Returns a count of the total number of rows.
The entry point for setting up a czv::count::RowCountBuilder by running RowCount::new().
Example
Let’s say we want to print the total number of non-header rows in our data:
use czv::{RowCount, Result};
fn main() -> Result<()> {
let data = "\
fruits,price
apple,2.50
banana,3.00
strawberry,1.50
";
let output = RowCount::new().file_data(data).execute()?;
println!("{output}"); // 3
Ok(())
}Implementations